import json
from oauth2client.client import SignedJwtAssertionCredentials

from django import template
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured

register = template.Library()

@register.inclusion_tag('otto_admin/analytics.html', takes_context=True)
def analytics(context, next = None):

    if not getattr(settings, 'OA_ANALYTICS_CREDENTIALS_JSON', None):
        raise ImproperlyConfigured('Analytics service account json path missing')

    if not getattr(settings, 'OA_ANALYTICS_VIEW_ID', None):
        raise ImproperlyConfigured('Analytics view id missing')

    # The scope for the OAuth2 request.
    SCOPE = 'https://www.googleapis.com/auth/analytics.readonly'

    # The location of the key file with the key data.
    KEY_FILEPATH = settings.OA_ANALYTICS_CREDENTIALS_JSON

    # Load the key file's private data.
    with open(KEY_FILEPATH) as key_file:
        _key_data = json.load(key_file)

    # Construct a credentials objects from the key data and OAuth2 scope.
    _credentials = SignedJwtAssertionCredentials(
        _key_data['client_email'], _key_data['private_key'], SCOPE)

    return {
        'token': _credentials.get_access_token().access_token,
        'view_id': settings.OA_ANALYTICS_VIEW_ID
    }

@register.filter(name='otto_admin_conf')
def otto_admin_conf(name):

    defaults = {
        'OA_COPYRIGHT': '2015 otto.to.it',
        'OA_SUPPORT_EMAIL': 'stefano.contini@otto.to.it',
        'OA_POWERED_BY': 'Otto srl',
        'OA_POWERED_BY_URL': 'http://www.otto.to.it',
    }

    return getattr(settings, name, defaults.get(name))



import os
#from distutils.core import setup
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-otto-admin',
    version='0.1.0',
    packages=['otto_admin', 'otto_admin.templatetags'],
    include_package_data=True,
    license='MIT License',
    description='Django admin customization app for django-suit',
    long_description=README,
    url='http://github.com/otto-torino/django-otto-admin',
    author='abidibo',
    author_email='abidibo@gmail.com',
    install_requires=[
        'Django',
        'django-suit',
        'google-api-python-client',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.5',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Topic :: Software Development',
        'Topic :: Software Development :: User Interfaces',
    ]
)
